import setuptools


setuptools.setup(
    name="pypitestmartin",
    version="0.1",
    python_requires=">=3.7",
    packages=setuptools.find_packages(),
    include_package_data=True,
    description="Test package",
    url="",
    author="Martin",
    author_email="",
    license="MIT",
    install_requires=[
    ],

)
